#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-5s8L3ZNhFwnJqimAwXsKdj
key:                  stack-2.9.3.1-5s8L3ZNhFwnJqimAwXsKdj
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  dc99c4eca121ab640e7a355db02c53b6
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-5s8L3ZNhFwnJqimAwXsKdj
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-BNAdu1zLoFX9s2bsz5V7NA array-0.5.6.0
    async-2.2.6-B1xPYkcAzs1LAdhNFIgAnG
    attoparsec-0.14.4-Jn9OdnAKkVz1hO2dwh0zwz base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    bytestring-0.11.5.3 casa-client-0.0.4-2p5zQKrrq1cDeNs9zoSWZe
    casa-types-0.0.3-9YpVB4Yujdi1jYyBNtS9Ly
    colour-2.3.7-73MWJ0W0aYRBKVtpFpWTXs
    conduit-1.3.6.1-7MjmOtU85HaB8wB7sCyBPV
    conduit-extra-1.3.8-J1pruM4XzBY6KaacrfmX7n containers-0.6.7
    crypton-1.0.4-5dxKfIBRa6R2YE55iyrOUy
    crypton-conduit-0.2.3-IdgxzCr2qtNBIOUBCwr5Wf deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-DutWM4qj2UOFoGYeyZgh2s
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-ETR6ZYppKlZHRmLOB2x6JA filepath-1.4.300.1
    fsnotify-0.4.4.0-FJfel2lvZWL6WD3jHl3xU1
    generic-deriving-1.14.7-EdpMS6VUjSWAYwhkxCiLC8
    hackage-security-0.6.3.2-F8YCghsneegL2pcd4QtNxr
    hashable-1.4.7.0-DeckboSXRoV2uaWXBDn9RA
    hi-file-parser-0.1.8.0-Bvk441ydkaRHh9rH3zE6NA
    hpack-0.38.0-1xOJOndjP0UHDjxUoVv7lq hpc-0.6.2.0
    http-client-0.7.19-LN5QT3bQF9y5GsNu19wbhO
    http-client-tls-0.3.6.4-BpM0XRSvwZ99JZv1J5vtXV
    http-conduit-2.3.9.1-9MREEIGDTJE2iYXOHTEmcN
    http-download-0.2.1.0-DZfCJsyXuiPKFzdOUUhATi
    http-types-0.12.4-57DQrkzau5HINFiGCpRQOB
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-ItYZYsAFccUCSY839NpaN1 mtl-2.3.1
    mustache-2.4.3.1-1npCybPbwiE88jmYiFmpNa
    neat-interpolation-0.5.1.4-AiHM9zBzR892ClJNtsyI9L
    network-uri-2.6.4.2-Fs1V3yFgC4iGyoDpGJIE7J
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-JRbhqUMlTBkCWkkrIaelno
    pantry-0.8.3-8diwAOUTQH5AMaxxcRVkPR
    path-0.9.6-FPswj21yURv88mENZJRf3U
    path-io-1.8.2-6795MZR1SVAL4C9h5F8gBE
    persistent-2.14.6.0-8WXih0Nu8qx1p1lVDUgiYw
    persistent-sqlite-2.13.2.0-AdQRzPIPCiG7S5DHOYAAMj pretty-1.1.3.6
    primitive-0.9.1.0-5zbRYrfoFPr4oGDF3kIYIh process-1.6.19.0
    project-template-0.2.1.0-1PLGchN88piJNU6zvsIfC
    random-1.2.1.3-2D6Xw54bvJBUzxlFqHjEz
    retry-0.9.3.1-AvBGPOoWaDPIoGQMpQu1Xb
    rio-0.1.24.0-6fEeJnSmO8M9mijhGz0veX
    rio-prettyprint-0.1.8.0-AYuAYEH7JW32qhAbDeZXvB
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    streaming-commons-0.2.3.1-FuWnzIh7SF0LrjyLH1EFAv
    tar-0.6.0.0-BnYLW1mSS5vCXQDYXNIv9f template-haskell-2.20.0.0
    temporary-1.3-BCLEeiJZS9p2VFxBOmtDaG text-2.0.2
    text-metrics-0.3.3-vzJAhxAqTO1RFrncdf4Rf
    th-reify-many-0.1.10-C82AomXtjFT3X5zoWwMzdc time-1.12.2
    tls-2.0.6-GRwo7CG1RJd8Igyy5Lhrq1 transformers-0.6.1.0
    typed-process-0.2.13.0-1TfKmUGZQT9CISkEO69QIp
    unicode-transforms-0.4.0.1-4no9zDVyLqxESgtwsdKbxY unix-2.8.4.0
    unix-compat-0.7.4.1-9XJmvTTI62BHh5oKVcMeBg
    unliftio-0.2.25.1-JwtBWAs5WUC67yAeM1UF4A
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk
    yaml-0.11.11.2-7UoXYkKWr4r4oNCJDlnyxG
    zip-archive-0.4.3.2-GF01YJ4Y7mT94q7blBMXAe
    zlib-0.7.1.0-C72dPpIBAem76SHRIfq7NC

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

